diff mbox series

[next] thermal/drivers: Fix spelling mistake "caliberation" -> "calibration"

Message ID 20211201131252.135535-1-colin.i.king@gmail.com
State New
Headers show
Series [next] thermal/drivers: Fix spelling mistake "caliberation" -> "calibration" | expand

Commit Message

Colin Ian King Dec. 1, 2021, 1:12 p.m. UTC
There are spelling mistakes in a comment and a dev_dbg message. Fix them.

Signed-off-by: Colin Ian King <colin.i.king@gmail.com>
---
 drivers/thermal/rzg2l_thermal.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
diff mbox series

Patch

diff --git a/drivers/thermal/rzg2l_thermal.c b/drivers/thermal/rzg2l_thermal.c
index d47d4a30cd6c..8d55e401d185 100644
--- a/drivers/thermal/rzg2l_thermal.c
+++ b/drivers/thermal/rzg2l_thermal.c
@@ -99,7 +99,7 @@  static int rzg2l_thermal_get_temp(void *devdata, int *temp)
 
 	/* The temperature Tj is calculated by the formula
 	 * Tj = (dsensor − calib1) * 165/ (calib0 − calib1) − 40
 	 * where calib0 and calib1 are the caliberation values.
 	 */
 	val = ((dsensor - priv->calib1) * (MCELSIUS(165) /
 		(priv->calib0 - priv->calib1))) - MCELSIUS(40);
@@ -209,7 +209,7 @@  static int rzg2l_thermal_probe(struct platform_device *pdev)
 	if (ret)
 		goto err;
 
-	dev_dbg(dev, "TSU probed with %s caliberation values",
+	dev_dbg(dev, "TSU probed with %s calibration values",
 		rzg2l_thermal_read(priv, OTPTSUTRIM_REG(0)) ?  "hw" : "sw");
 
 	return 0;
@@ -99,7 +99,7 @@  static int rzg2l_thermal_get_temp(void *devdata, int *temp)
 	/* The temperature Tj is calculated by the formula
 	 * Tj = (dsensor − calib1) * 165/ (calib0 − calib1) − 40
-	 * where calib0 and calib1 are the caliberation values.
+	 * where calib0 and calib1 are the calibration values.
 	 */
 	val = ((dsensor - priv->calib1) * (MCELSIUS(165) /